import { ChakraProvider, ColorModeScript, extendTheme } from '@chakra-ui/react'
import { QueryClient, QueryClientProvider } from 'react-query'

import { FatalErrorBoundary, RedwoodProvider } from '@redwoodjs/web'

import { theme } from './design/theme'
import { DevFatalError } from './pages/fatal-error'
import Routes from './Routes'

const extendedTheme = extendTheme(theme)

const App = () => {
  const queryClient = new QueryClient()
  queryClient.setDefaultOptions({
    queries: {
      staleTime: 1000 * 60,
    },
  })

  return (
    <FatalErrorBoundary page={DevFatalError}>
      <RedwoodProvider titleTemplate="%PageTitle | %AppTitle">
        <ColorModeScript />
        <QueryClientProvider client={queryClient}>
          <ChakraProvider theme={extendedTheme}>
            <Routes />
          </ChakraProvider>
        </QueryClientProvider>
      </RedwoodProvider>
    </FatalErrorBoundary>
  )
}
export default App
