import React from 'react'

import { Box, Button, HStack, Text, VStack } from '@chakra-ui/react'

import { useParams } from '@redwoodjs/router'

import { Animations } from 'src/pages/animations'
import { Implementations } from 'src/pages/implementations'
import { GetPatternQuery } from '../query-builder'
import { RemovePatternButton } from '../remove-pattern'
import { FormalizationList } from './formalizations-list'

export const PatternDetails: React.FC = () => {
  const { id } = useParams()

  const getPatternQuery = GetPatternQuery.useQuery({ id })

  const pattern = getPatternQuery.data

  if (!pattern) {
    return null
  }

  return (
    <VStack>
      <VStack display="flex" alignItems="start" px="2" minW="80vw">
        <Text fontWeight="bold" fontSize="x-large">
          {pattern.name}
        </Text>
        <Text wordBreak="break-all">{pattern.description}</Text>
      </VStack>
      <VStack w="full" justifyContent="center" spacing="8">
        <VStack alignItems="flex-start">
          <Text pl="2" fontWeight="bold">
            Implementaciones
          </Text>
          <Implementations patternId={pattern.id} />
        </VStack>
        <VStack alignItems="flex-start">
          <Text pl="2" fontWeight="bold">
            Animaciones
          </Text>
          <Animations patternId={pattern.id} />
        </VStack>
      </VStack>
      <Box w="full" justifyContent="flex-end" display="flex">
        <RemovePatternButton pattern={pattern}>
          <Button>Eliminar</Button>
        </RemovePatternButton>
      </Box>
      <FormalizationList formalizations={pattern.formalizations} />
    </VStack>
  )
}
