import { AxiosError, toFormData } from 'axios'
import { useMutation as useRQMutation, UseMutationOptions } from 'react-query'
import { CreateFormalizationRequest, Formalization } from 'src/models'
import axiosService from 'src/services/axios-service'

export namespace CreateFormalizationMutation {
  export type Params = CreateFormalizationRequest
  export type Response = Formalization

  const key = ['create', 'formalization']

  export const mutationFn = (params: Params) =>
    axiosService
      .post<Response>(`/formalization/`, toFormData(params))
      .then((res) => res.data)

  export const useMutation = (
    options: UseMutationOptions<
      Response,
      AxiosError,
      CreateFormalizationRequest
    > = {}
  ) => {
    return useRQMutation(mutationFn, { ...options, mutationKey: key })
  }
}
